// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "purpose_fileitemaction_plugin_debug.h"


Q_LOGGING_CATEGORY(PURPOSE_FILEITEMACTION_PLUGIN_LOG, "kf.kio.widgets.fileitemactions.purpose", QtInfoMsg)

