// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "purpose_external_process_debug.h"


Q_LOGGING_CATEGORY(PURPOSE_EXTERNAL_PROCESS_LOG, "kf.purpose.externalprocess", QtInfoMsg)

